.menu.svelte-1umj7l5.svelte-1umj7l5{position:relative;margin:0 auto;overflow:hidden;border-radius:50%}.quarter.svelte-1umj7l5.svelte-1umj7l5{position:absolute;width:50%;height:50%;transition:opacity .2s;cursor:pointer;border:solid .5px rgba(0,0,0,.5);font-weight:700;font-size:18px}.quarter:hover.active.svelte-1umj7l5.svelte-1umj7l5{opacity:.5}.content.svelte-1umj7l5.svelte-1umj7l5{text-align:center;width:100%;transform-origin:center center;position:absolute;top:50%;left:50%}.quarter1.svelte-1umj7l5.svelte-1umj7l5{top:0;left:0;color:red;background-color:#ff000080;border-radius:100% 0 0}.quarter1.svelte-1umj7l5 .content.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(-45deg)}.quarter2.svelte-1umj7l5.svelte-1umj7l5{top:0;right:0;color:#00a400;background-color:#00a40080;border-radius:0 100% 0 0}.quarter2.svelte-1umj7l5 .content.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(45deg)}.quarter3.svelte-1umj7l5.svelte-1umj7l5{cursor:default;bottom:0;left:0;color:#00f3;background-color:#0000ff1a;border-radius:0 0 0 100%}.quarter3.svelte-1umj7l5 .content.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(45deg)}.quarter4.svelte-1umj7l5.svelte-1umj7l5{cursor:default;bottom:0;right:0;color:#78780033;background-color:#7878001a;border-radius:0 0 100%}.quarter4.svelte-1umj7l5 .content.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(-45deg)}.logo.svelte-1umj7l5.svelte-1umj7l5{position:absolute;width:50%;height:50%;left:50%;top:50%;transform:translate(-50%,-50%);background-color:#fff;border-radius:50%}img.svelte-1umj7l5.svelte-1umj7l5{position:relative;width:100%;height:100%;border-radius:50%}.links.svelte-1umj7l5.svelte-1umj7l5{font-size:20px;display:block;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center center;width:0;height:0;background-color:#fffffff2;transition:all .2s ease-out;border-radius:50%;overflow:hidden}.links.active.svelte-1umj7l5.svelte-1umj7l5{width:100%;height:100%}.sublink.svelte-1umj7l5.svelte-1umj7l5{text-align:center;position:absolute;width:50%;height:50%}.sublink.svelte-1umj7l5 a.svelte-1umj7l5{position:absolute;top:50%;left:50%;transform-origin:center center}.sublink.l1.svelte-1umj7l5.svelte-1umj7l5{top:0;left:0}.sublink.l1.svelte-1umj7l5 a.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(-45deg)}.sublink.l2.svelte-1umj7l5.svelte-1umj7l5{top:0;right:0}.sublink.l2.svelte-1umj7l5 a.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(45deg)}.sublink.l3.svelte-1umj7l5.svelte-1umj7l5{bottom:0;left:0}.sublink.l3.svelte-1umj7l5 a.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(45deg)}.sublink.l4.svelte-1umj7l5.svelte-1umj7l5{bottom:0;right:0}.sublink.l4.svelte-1umj7l5 a.svelte-1umj7l5{transform:translate(-50%,-50%) rotate(-45deg)}.close.svelte-1umj7l5.svelte-1umj7l5{position:absolute;width:10%;height:10%;top:50%;left:50%;transform:translate(-50%,-50%);border-radius:50%;border:none;background-color:#0000001a;transition:background-color .2s;font-size:40px}.close.svelte-1umj7l5 img.svelte-1umj7l5{position:absolute;width:70%;height:70%;top:50%;left:50%;transform:translate(-50%,-50%)}.close.svelte-1umj7l5.svelte-1umj7l5:hover{background-color:#0003}
