import{s as _,l as c,e as m,a as p,c as d,m as h,g as v,o as $,i as u,u as g,p as T,q,f}from"../chunks/scheduler.Bw2O2KLD.js";import{S as y,i as L,t as w,a as C}from"../chunks/index.Cyrvb228.js";function H(l){let s,r='<div class="col"><h1>The Transition Pathway</h1></div>',i,a;const n=l[1].default,e=c(n,l,l[0],null);return{c(){s=m("div"),s.innerHTML=r,i=p(),e&&e.c(),this.h()},l(t){s=d(t,"DIV",{class:!0,"data-svelte-h":!0}),h(s)!=="svelte-1gdh9qu"&&(s.innerHTML=r),i=v(t),e&&e.l(t),this.h()},h(){$(s,"class","row")},m(t,o){u(t,s,o),u(t,i,o),e&&e.m(t,o),a=!0},p(t,[o]){e&&e.p&&(!a||o&1)&&g(e,n,t,t[0],a?q(n,t[0],o,null):T(t[0]),null)},i(t){a||(w(e,t),a=!0)},o(t){C(e,t),a=!1},d(t){t&&(f(s),f(i)),e&&e.d(t)}}}function M(l,s,r){let{$$slots:i={},$$scope:a}=s;return l.$$set=n=>{"$$scope"in n&&r(0,a=n.$$scope)},[a,i]}class D extends y{constructor(s){super(),L(this,s,M,H,_,{})}}export{D as component};
