const _={"1.9.0":{capex_yearly:"cost_capex_yearly",opex_yearly:"cost_opex_yearly",cost_opex_total:"cost_opex_yearly_total",cost_opex:"cost_opex_variable",cost_capex_total:"cost_capex_yearly_total",cost_capex:"cost_capex_overnight"}};function a(r,o){let t=r.split("."),l=o.split(".");for(let e=0;e<3;e++){if(Number(t[e])<Number(l[e]))return!0;if(Number(t[e])>Number(l[e]))return!1}return!1}function s(r,o="0.0.0"){let t=null;for(let e of Object.keys(_))a(e,o)&&(t=e);let l;return t===null||!(r in _[t])?l=r:l=_[t][r],l}export{s as g};
