.modal-open,.overflow-noscroll{overflow:hidden;padding-right:0}span.svelte-f2gsno{display:contents}.btn-group.svelte-1os93qe.svelte-1os93qe{opacity:0;transition:opacity .3s}.canvas-container.svelte-1os93qe:hover>.btn-group.svelte-1os93qe{opacity:1}
